@@ -72,6 +72,11 @@ pref("network.protocol-handler.warn-external.nntp", false);
 pref("network.protocol-handler.warn-external.snews", false);
 pref("network.protocol-handler.warn-external.webcal", false);
 
+// don't warn
+pref("network.protocol-handler.warn-external.rtsp", false);
+pref("network.protocol-handler.warn-external.mms", false);
+pref("network.protocol-handler.warn-external.mmsh", false);
+
 // disable xpinstall
 pref("xpinstall.enabled", false);
 
@@ -94,6 +99,7 @@ pref("browser.enable_automatic_image_resizing", false);
 pref("signon.rememberSignons", true);
 pref("signon.expireMasterPassword", false);
 pref("signon.SignonFileName", "signons.txt");
+pref("signon.autofillForms", true);
 
 // use system colours
 pref("browser.display.use_system_colors", true);
@@ -115,7 +121,7 @@ pref("browser.blink_allowed", false);
 pref("snav.enabled", true);
 
 // don't leak UI language, and don't default to "en-US"
-pref("general.useragent.locale", "en")
+pref("general.useragent.locale", "en");
 
 // spellcheck
 // pref("extensions.spellcheck.inline.max-misspellings", -1);
@@ -130,3 +136,17 @@ pref("print.show_print_progress", true);
 pref("print.printer_list", "");
 pref("postscript.enabled", true);
 pref("postscript.cups.enabled", false);
+
+// sites stealthly storing unlimited amount of data? no thanks
+pref("dom.storage.enabled", false);
+
+// warn about about:config
+pref("general.warnOnAboutConfig", true);
+
+// Whether delete and backspace should immediately delete characters not
+// visually adjacent to the caret, or adjust the visual position of the caret
+// on the first keypress and delete the character on a second keypress
+// (added in bug https://bugzilla.mozilla.org/show_bug.cgi?id=328834)
+// set to true for parity with gtk entries
+pref("bidi.edit.delete_immediately", true);
+
