@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2003 Marco Pesenti Gritti
+ *  Copyright © 2000-2003 Marco Pesenti Gritti
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-download.h,v 1.6 2004/09/13 10:24:56 chpe Exp $
+ *  $Id: ephy-download.h 6589 2006-09-13 11:49:01Z chpe $
  */
 
 #ifndef EPHY_DOWNLOAD_H
@@ -33,9 +33,9 @@ G_BEGIN_DECLS
 #define EPHY_IS_DOWNLOAD_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), EPHY_TYPE_DOWNLOAD))
 #define EPHY_DOWNLOAD_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), EPHY_TYPE_DOWNLOAD, EphyDownloadClass))
 
-typedef struct EphyDownload EphyDownload;
-typedef struct EphyDownloadClass EphyDownloadClass;
-typedef struct EphyDownloadPrivate EphyDownloadPrivate;
+typedef struct _EphyDownload EphyDownload;
+typedef struct _EphyDownloadClass EphyDownloadClass;
+typedef struct _EphyDownloadPrivate EphyDownloadPrivate;
 
 typedef enum
 {
@@ -46,7 +46,7 @@ typedef enum
 	EPHY_DOWNLOAD_FAILED
 } EphyDownloadState;
 
-struct EphyDownload
+struct _EphyDownload
 {
         GObject parent;
 
@@ -54,7 +54,7 @@ struct EphyDownload
 	EphyDownloadPrivate *priv;
 };
 
-struct EphyDownloadClass
+struct _EphyDownloadClass
 {
         GObjectClass parent_class;
 
@@ -62,9 +62,9 @@ struct EphyDownloadClass
 	char * 		  (* get_target)           (EphyDownload *download);
 	char * 		  (* get_mime)             (EphyDownload *download);
 	int    		  (* get_percent)          (EphyDownload *download);
-	long   		  (* get_current_progress) (EphyDownload *download);
-	long   		  (* get_total_progress)   (EphyDownload *download);
-	long   		  (* get_elapsed_time)	   (EphyDownload *download);
+	gint64 		  (* get_current_progress) (EphyDownload *download);
+	gint64 		  (* get_total_progress)   (EphyDownload *download);
+	gint64 		  (* get_elapsed_time)	   (EphyDownload *download);
 	void   		  (* cancel)               (EphyDownload *download);
 	void   		  (* pause)                (EphyDownload *download);
 	void   		  (* resume)               (EphyDownload *download);
@@ -92,13 +92,13 @@ int                ephy_download_get_percent          (EphyDownload *download);
 
 EphyDownloadState  ephy_download_get_state	      (EphyDownload *download);	   
 
-long               ephy_download_get_current_progress (EphyDownload *download);
+gint64		   ephy_download_get_current_progress (EphyDownload *download);
 
-long               ephy_download_get_total_progress   (EphyDownload *download);
+gint64		   ephy_download_get_total_progress   (EphyDownload *download);
 
-long		   ephy_download_get_elapsed_time     (EphyDownload *download);
+gint64		   ephy_download_get_elapsed_time     (EphyDownload *download);
 
-long		   ephy_download_get_remaining_time   (EphyDownload *download);
+gint64		   ephy_download_get_remaining_time   (EphyDownload *download);
 
 void		   ephy_download_cancel	      	      (EphyDownload *download);
 
