@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ContentHandler.cpp,v 1.94.2.1 2006/09/13 11:48:34 chpe Exp $
+ *  $Id: ContentHandler.cpp 6868 2007-01-28 21:10:37Z jframeau $
  */
 
 #include "mozilla-config.h"
@@ -93,6 +93,18 @@ GContentHandler::Show (nsIHelperAppLauncher *aLauncher,
 	/* FIXME: handle aForced / aReason argument in some way? */
 
 	mContext = aContext;
+
+	/* Check for a potential veto */
+	nsCOMPtr<nsIDOMWindow> window (do_GetInterface (aContext));
+	GtkWidget *embed = EphyUtils::FindEmbed (window);
+	if (EPHY_IS_EMBED (embed))
+	{
+		if (g_object_get_data (G_OBJECT (embed), "content-handler-deny"))
+		{
+			return NS_OK;
+		}
+	}
+
 	mLauncher = aLauncher;
 	rv = Init ();
 	NS_ENSURE_SUCCESS (rv, rv);
@@ -365,6 +377,7 @@ NS_METHOD GContentHandler::MIMEInitiateAction (void)
 	{
 		const char *id = gnome_vfs_mime_application_get_desktop_id (mHelperApp);
 
+		/* FIXME! menu editing can make this check fail!!!! */
 		if (id && strcmp (id, "epiphany.desktop") == 0)
 		{
 			mHelperApp = nsnull;
