@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2000-2004 Marco Pesenti Gritti
- *  Copyright (C) 2003, 2004, 2005 Christian Persch
+ *  Copyright © 2000-2004 Marco Pesenti Gritti
+ *  Copyright © 2003, 2004, 2005 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyBrowser.cpp,v 1.108 2006/05/10 18:07:00 chpe Exp $
+ *  $Id: EphyBrowser.cpp 6845 2007-01-23 17:42:11Z chpe $
  */
 
 #include "mozilla-config.h"
@@ -67,6 +67,8 @@
 #include <nsIHistoryEntry.h>
 #include <nsIInterfaceRequestor.h>
 #include <nsIInterfaceRequestorUtils.h>
+#include <nsIPrintSettings.h>
+#include <nsIPrintSettingsService.h>
 #include <nsIScriptSecurityManager.h>
 #include <nsIServiceManager.h>
 #include <nsISHEntry.h>
@@ -98,14 +100,16 @@
 
 #include "ephy-debug.h"
 #include "ephy-embed.h"
+#include "ephy-embed-shell.h"
 #include "ephy-string.h"
 #include "ephy-zoom.h"
 #include "mozilla-embed-event.h"
 #include "mozilla-embed.h"
-#include "print-dialog.h"
 
+#include "AutoJSContextStack.h"
 #include "EphyUtils.h"
 #include "EventContext.h"
+#include "GeckoPrintService.h"
 
 #include "EphyBrowser.h"
 
@@ -673,7 +677,20 @@ nsresult EphyBrowser::Print ()
 	nsCOMPtr<nsIWebBrowserPrint> print(do_GetInterface(mWebBrowser));
 	NS_ENSURE_TRUE (print, NS_ERROR_FAILURE);
 
-	return  print->Print (nsnull, nsnull);
+	nsCOMPtr<nsIPrintSettingsService> printSettingsService
+		(do_GetService("@mozilla.org/gfx/printsettings-service;1"));
+	NS_ENSURE_STATE (printSettingsService);
+
+	nsCOMPtr<nsIPrintSettings> settings;
+	printSettingsService->GetNewPrintSettings (getter_AddRefs (settings));
+	NS_ENSURE_STATE (settings);
+
+	nsresult rv;
+	AutoJSContextStack stack;
+	rv = stack.Init ();
+	NS_ENSURE_SUCCESS (rv, rv);
+
+	return  print->Print (settings, nsnull);
 }
 
 nsresult EphyBrowser::SetPrintPreviewMode (PRBool previewMode)
@@ -682,21 +699,31 @@ nsresult EphyBrowser::SetPrintPreviewMode (PRBool previewMode)
 
 	NS_ENSURE_TRUE (mWebBrowser, NS_ERROR_FAILURE);
 
-	nsCOMPtr<nsIWebBrowserPrint> print(do_GetInterface(mWebBrowser));
-	NS_ENSURE_TRUE (print, NS_ERROR_FAILURE);
+	nsCOMPtr<nsIWebBrowserPrint> print (do_GetInterface (mWebBrowser));
+	NS_ENSURE_STATE (print);
 
 	if (previewMode)
 	{
-		EmbedPrintInfo *info;
+		nsCOMPtr<nsIPrintSettingsService> printSettingsService
+			(do_GetService("@mozilla.org/gfx/printsettings-service;1"));
+		NS_ENSURE_STATE (printSettingsService);
 
 		nsCOMPtr<nsIPrintSettings> settings;
-		print->GetGlobalPrintSettings (getter_AddRefs(settings));
+		printSettingsService->GetNewPrintSettings (getter_AddRefs (settings));
+		NS_ENSURE_STATE (settings);
 
-		info = ephy_print_get_print_info ();
-		EphyUtils::CollatePrintSettings (info, settings, TRUE);
-		ephy_print_info_free (info);
+		EphyEmbedShell *shell = ephy_embed_shell_get_default ();
+		rv = GeckoPrintService::TranslateSettings (ephy_embed_shell_get_print_settings (shell),
+							   ephy_embed_shell_get_page_setup (shell),
+							   NULL,
+							   nsCString(),
+							   PR_FALSE,
+							   settings);
 
-		rv = print->PrintPreview (nsnull, mDOMWindow, nsnull);
+		if (NS_SUCCEEDED (rv))
+		{
+			rv = print->PrintPreview (settings, mDOMWindow, nsnull);
+		}
 	}
 	else
 	{
@@ -705,7 +732,7 @@ nsresult EphyBrowser::SetPrintPreviewMode (PRBool previewMode)
 		rv = print->GetDoingPrintPreview(&isPreview);
 		NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
-		if (isPreview == PR_TRUE)
+		if (isPreview)
 		{
 			rv = print->ExitPrintPreview();
 		}
@@ -1498,3 +1525,55 @@ EphyBrowser::Close ()
 
 	return domWin->Close();
 }
+
+nsresult
+EphyBrowser::GetPIDOMWindow(nsPIDOMWindow **aPIWin)
+{
+  *aPIWin = nsnull;
+
+  // get the private DOM window
+  nsCOMPtr<nsPIDOMWindow> domWindowPrivate = do_QueryInterface(mDOMWindow);
+
+  // and the root window for that DOM window
+  *aPIWin = domWindowPrivate->GetPrivateRoot();
+
+  if (*aPIWin) 
+  {
+    NS_ADDREF(*aPIWin);
+    return NS_OK;
+  }
+
+  return NS_ERROR_FAILURE;
+
+}
+
+nsresult
+EphyBrowser::LoadURI(const char *aURI,
+		     PRUint32 aLoadFlags,
+		     nsIURI *aReferrer)
+{
+	nsString uURI;
+	nsresult rv = NS_OK;
+
+ 	NS_CStringToUTF16 (nsCString (aURI), NS_CSTRING_ENCODING_UTF8, uURI);
+
+	if (uURI.Length() == 0) return NS_OK;
+ 
+	nsCOMPtr<nsIWebNavigation> contentNav = do_QueryInterface (mWebBrowser);
+	NS_ENSURE_TRUE (contentNav, NS_ERROR_FAILURE);
+
+	nsCOMPtr<nsPIDOMWindow> piWin;
+	rv = GetPIDOMWindow(getter_AddRefs(piWin));
+  	NS_ENSURE_SUCCESS (rv, rv);
+
+	nsAutoPopupStatePusher popupStatePusher(piWin, openAllowed);
+
+	rv = contentNav->LoadURI(uURI.get(),   // URI string
+			 	 aLoadFlags,   // Load flags
+			 	 aReferrer,    // Referring URI
+			 	 nsnull,       // Post data
+			 	 nsnull);      // extra headers
+
+	return rv;
+}
+
