@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2003 Christian Persch
- *  Copyright (C) 2003 Marco Pesenti Gritti
+ *  Copyright © 2003 Christian Persch
+ *  Copyright © 2003 Marco Pesenti Gritti
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphySingle.cpp,v 1.27 2006/06/01 19:35:32 jframeau Exp $
+ *  $Id: EphySingle.cpp 6589 2006-09-13 11:49:01Z chpe $
  */
 
 #include "mozilla-config.h"
@@ -148,20 +148,20 @@ EphySingle::EmitPermissionNotification (const char *name,
 nsresult
 EphySingle::ExamineCookies (nsISupports *aSubject)
 {
-	nsCOMPtr<nsIPropertyBag2> props = do_QueryInterface(aSubject);
-	NS_ENSURE_TRUE (props, NS_ERROR_FAILURE);
-
 	PRBool isBlockingCookiesChannel = PR_FALSE;
-	props->GetPropertyAsBool(
-			NS_LITERAL_STRING("epiphany-blocking-cookies"), 
-			&isBlockingCookiesChannel);
-	if (isBlockingCookiesChannel)
-	{
-		nsCOMPtr<nsIHttpChannel> channel = do_QueryInterface(aSubject);
-		NS_ENSURE_TRUE (channel, NS_ERROR_FAILURE);
 
-		channel->SetRequestHeader(NS_LITERAL_CSTRING("Cookie"),
-					  EmptyCString(), PR_FALSE);
+	nsCOMPtr<nsIPropertyBag2> props (do_QueryInterface(aSubject));
+	if (props &&
+	    NS_SUCCEEDED (props->GetPropertyAsBool(
+			  NS_LITERAL_STRING("epiphany-blocking-cookies"), 
+			  &isBlockingCookiesChannel)) &&
+	    isBlockingCookiesChannel)
+	{
+		nsCOMPtr<nsIHttpChannel> httpChannel (do_QueryInterface(aSubject));
+
+		if (httpChannel)
+			httpChannel->SetRequestHeader(NS_LITERAL_CSTRING("Cookie"),
+						      EmptyCString(), PR_FALSE);
 	}
 
 	return NS_OK;
