@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2003 Christian Persch
- *  Copyright (C) 2003 Marco Pesenti Gritti
+ *  Copyright © 2003 Christian Persch
+ *  Copyright © 2003 Marco Pesenti Gritti
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphySingle.h,v 1.5 2006/05/10 18:07:00 chpe Exp $
+ *  $Id: EphySingle.h 6589 2006-09-13 11:49:01Z chpe $
  */
 
 #ifndef EPHY_SINGLE_H
@@ -50,7 +50,10 @@ public:
 protected:
 	nsresult EmitCookieNotification (const char *name, nsISupports *aSubject);
 	nsresult EmitPermissionNotification (const char *name, nsISupports *aSubject);
-
+	nsresult ExamineResponse (nsISupports *aSubject);	
+	nsresult ExamineRequest (nsISupports *aSubject);	
+	nsresult ExamineCookies (nsISupports *aSubject);	
+	
 private:
 	nsCOMPtr<nsIObserverService> mObserverService;
 	EphyEmbedSingle *mOwner;
