@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2006 Christian Persch
+ *  Copyright © 2006 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: GeckoPrintService.h,v 1.2 2006/07/21 17:25:49 chpe Exp $
+ *  $Id: GeckoPrintService.h 6845 2007-01-23 17:42:11Z chpe $
  */
 
 #ifndef GECKO_PRINT_SERVICE_H
@@ -23,6 +23,7 @@
 
 #include <gtk/gtkpagesetup.h>
 #include <gtk/gtkprintsettings.h>
+#include <gtk/gtkprinter.h>
 
 #include <nsIPrintingPromptService.h>
 
@@ -44,7 +45,7 @@ public:
 	GeckoPrintService();
 	virtual ~GeckoPrintService();
 
-	static nsresult TranslateSettings (GtkPrintSettings*, GtkPageSetup *, const nsACString&, PRBool, nsIPrintSettings*);
+	static nsresult TranslateSettings (GtkPrintSettings*, GtkPageSetup *, GtkPrinter *, const nsACString&, PRBool, nsIPrintSettings*);
 
 private:
 	nsresult PrintUnattended (nsIDOMWindow *, nsIPrintSettings *);
