@@ -16,7 +16,7 @@
  *
  * The Initial Developer of the Original Code is
  * Netscape Communications Corporation.
- * Portions created by the Initial Developer are Copyright (C) 2002
+ * Portions created by the Initial Developer are Copyright © 2002
  * the Initial Developer. All Rights Reserved.
  *
  * Contributor(s):
@@ -38,7 +38,7 @@
  *
  * ***** END LICENSE BLOCK *****
  *
- * $Id: MozDownload.cpp,v 1.83 2006/07/06 21:56:27 jframeau Exp $
+ * $Id: MozDownload.cpp 6589 2006-09-13 11:49:01Z chpe $
  */
 
 #include "mozilla-config.h"
@@ -79,6 +79,9 @@
 
 #include "MozDownload.h"
 
+/* Minimum time between progress updates */
+#define PROGRESS_RATE 500000 /* microsec */
+
 const char* const persistContractID = "@mozilla.org/embedding/browser/nsWebBrowserPersist;1";
 
 MozDownload::MozDownload() :
@@ -143,7 +146,7 @@ MozDownload::Init (nsIURI *aSource,
 	mTotalProgress = 0;
 	mCurrentProgress = 0;
 	mPercentComplete = 0;
-	mInterval = 200000; /* microsec */
+	mInterval = PROGRESS_RATE;
 	mLastUpdate = mStartTime;
 	mMIMEInfo = aMIMEInfo;
 
