@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2000-2003 Marco Pesenti Gritti
- *  Copyright (C) 2004 Christian Persch
+ *  Copyright © 2000-2003 Marco Pesenti Gritti
+ *  Copyright © 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-embed-event.cpp,v 1.12 2006/05/10 18:07:00 chpe Exp $
+ *  $Id: mozilla-embed-event.cpp 6589 2006-09-13 11:49:01Z chpe $
  */
 
 #include "mozilla-config.h"
@@ -52,7 +52,7 @@ mozilla_embed_event_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (MozillaEmbedEventClass),
 			NULL, /* base_init */
@@ -65,7 +65,7 @@ mozilla_embed_event_get_type (void)
 			(GInstanceInitFunc) mozilla_embed_event_init
 		};
 
-		static const GInterfaceInfo embed_event_info =
+		const GInterfaceInfo embed_event_info =
 		{
 			(GInterfaceInitFunc) ephy_embed_event_iface_init,
         		NULL,
