@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2003, 2004  Marco Pesenti Gritti
- *  Copyright (C) 2003, 2004, 2005  Christian Persch
+ *  Copyright © 2003, 2004  Marco Pesenti Gritti
+ *  Copyright © 2003, 2004, 2005  Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: egg-editable-toolbar.h,v 1.21 2006/01/30 22:13:07 paharvey Exp $
+ *  $Id: egg-editable-toolbar.h 6589 2006-09-13 11:49:01Z chpe $
  */
 
 #ifndef EGG_EDITABLE_TOOLBAR_H
@@ -84,6 +84,9 @@ GtkWidget *         egg_editable_toolbar_get_selected    (EggEditableToolbar   *
 void                egg_editable_toolbar_set_selected    (EggEditableToolbar   *etoolbar,
 							  GtkWidget            *widget);
 
+void              egg_editable_toolbar_add_visibility    (EggEditableToolbar   *etoolbar,
+							  const char           *path);
+
 /* Private Functions */
 
 GtkWidget 	   *_egg_editable_toolbar_new_separator_image (void);
