@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-location-entry.c,v 1.79.2.2 2006/09/13 11:48:49 chpe Exp $
+ *  $Id: ephy-location-entry.c 6744 2006-12-17 19:07:04Z chpe $
  */
 
 #include "config.h"
@@ -107,6 +107,7 @@ static const GtkTargetEntry url_drag_types [] =
 };
 
 static const GdkColor fallback_bg_colour = { 0, 0xf7f7, 0xf7f7, 0xbebe }; /* yellow-ish */
+static const GdkColor fallback_fg_colour = { 0, 0, 0, 0 }; /* black */
 
 static void ephy_location_entry_class_init (EphyLocationEntryClass *klass);
 static void ephy_location_entry_init (EphyLocationEntry *le);
@@ -208,8 +209,7 @@ ephy_location_entry_style_set (GtkWidget *widget,
 	}
 	else
 	{
-		/* FIXME: fall back to black text maybe? */
-		priv->secure_fg_colour = widget->style->text[GTK_STATE_NORMAL];
+		priv->secure_fg_colour = fallback_fg_colour;
 	}
 
 	if (bg_colour != NULL)
