@@ -1,11 +1,11 @@
 /*
- *  Copyright (C) 2005 Jorn Baayen <jbaayen@gnome.org>
- *  Copyright (C) 2005 Christian Persch
+ *  Copyright © 2005 Jorn Baayen <jbaayen@gnome.org>
+ *  Copyright © 2005 Christian Persch
  *
  *  Based on the work of:
  *
- *  Copyright (C) 2004 Bastien Nocera <hadess@hadess.net>
- *  Copyright (C) 2002 David A. Schleef <ds@schleef.org>
+ *  Copyright © 2004 Bastien Nocera <hadess@hadess.net>
+ *  Copyright © 2002 David A. Schleef <ds@schleef.org>
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -22,7 +22,7 @@
  *  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  *  Boston, MA 02111-1307, USA.
  *
- *  $Id: plugin.cpp,v 1.4 2006/03/12 22:25:03 chpe Exp $
+ *  $Id: plugin.cpp 6589 2006-09-13 11:49:01Z chpe $
  */
 
 #include "mozilla-config.h"
@@ -447,7 +447,7 @@ plugin_get_value (NPP instance,
 		break;
 
 	case NPPVpluginNeedsXEmbed:
-		*((PRBool *) value) = PR_FALSE;
+		*((NPBool *) value) = PR_FALSE;
 		break;
 
 	default:
