@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: ephy-bookmarks-editor.c,v 1.195.2.2 2006/09/13 11:49:01 chpe Exp $
+ * $Id: ephy-bookmarks-editor.c 6827 2007-01-17 23:55:39Z diegoe $
  */
 
 #include "config.h"
@@ -1363,7 +1363,7 @@ ephy_bookmarks_editor_update_menu (EphyBookmarksEditor *editor)
 		EphyNode *node = selected->data;
 		char name[EPHY_BOOKMARK_ACTION_NAME_BUFFER_SIZE];
 
-		g_return_if_fail (node != NULL);
+		if (node == NULL) return;
 
 		mutable = !ephy_node_get_property_boolean (node, EPHY_NODE_BMK_PROP_IMMUTABLE);
 		
