@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2005 Peter Harvey
+ *  Copyright © 2005 Peter Harvey
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-related-action.c,v 1.4 2006/02/09 13:52:45 chpe Exp $
+ *  $Id: ephy-related-action.c 6589 2006-09-13 11:49:01Z chpe $
  */
 
 #include "config.h"
@@ -128,7 +128,7 @@ ephy_related_action_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphyRelatedActionClass),
 			NULL, /* base_init */
@@ -140,7 +140,7 @@ ephy_related_action_get_type (void)
 			0,   /* n_preallocs */
 			NULL /* instance_init */
 		};
-		static const GInterfaceInfo link_info = 
+		const GInterfaceInfo link_info = 
 		{
 			(GInterfaceInitFunc) iface_init,
 			NULL,
