@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id$
+ *  $Id: ephy-dbus.c 6863 2007-01-28 20:31:29Z chpe $
  */
 
 #include "config.h"
@@ -244,7 +244,7 @@ ephy_dbus_connect_to_session_bus (EphyDbus *ephy_dbus,
 	priv->session_bus = dbus_g_bus_get (DBUS_BUS_SESSION, error);
 	if (priv->session_bus == NULL)
 	{
-		g_warning("Unable to connect to session bus: %s", error ? (*error)->message : "");
+		g_warning("Unable to connect to session bus: %s", error && *error ? (*error)->message : "");
 		return FALSE;
 	}
 
