@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2004 Tommi Komulainen
- *  Copyright (C) 2004, 2005 Christian Persch
+ *  Copyright © 2004 Tommi Komulainen
+ *  Copyright © 2004, 2005 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: ephy-find-toolbar.c,v 1.27 2006/01/30 13:32:01 chpe Exp $
+ *  $Id: ephy-find-toolbar.c 6589 2006-09-13 11:49:01Z chpe $
  */
 
 #include "config.h"
@@ -101,17 +101,6 @@ get_find (EphyFindToolbar *toolbar)
 	return priv->find;
 }
 
-static void
-set_controls (EphyFindToolbar *toolbar,
-	      gboolean can_find_next,
-	      gboolean can_find_prev)
-{
-	EphyFindToolbarPrivate *priv = toolbar->priv;
-
-	gtk_widget_set_sensitive (GTK_WIDGET (priv->next), can_find_next);
-	gtk_widget_set_sensitive (GTK_WIDGET (priv->prev), can_find_prev);
-}
-
 static void
 set_status (EphyFindToolbar *toolbar,
 	    EphyEmbedFindResult result)
@@ -151,16 +140,6 @@ clear_status (EphyFindToolbar *toolbar)
 			    priv->links_only ? _("Find links:") : _("Find:"));
 }
 
-static void
-tab_content_changed_cb (EphyEmbed *embed,
-			const char *uri,
-			EphyFindToolbar *toolbar)
-{
-	set_controls (toolbar, TRUE, TRUE);
-}
-
-#ifdef HAVE_TYPEAHEADFIND
-
 /* Code adapted from gtktreeview.c:gtk_tree_view_key_press() and
  * gtk_tree_view_real_start_interactive_seach()
  */
@@ -195,8 +174,6 @@ tab_search_key_press_cb (EphyEmbed *embed,
 	return FALSE;
 }
 
-#endif /* HAVE_TYPEAHEADFIND */
-
 static void
 find_next_cb (EphyFindToolbar *toolbar)
 {
@@ -216,10 +193,8 @@ entry_changed_cb (GtkEntry *entry,
 	EphyFindToolbarPrivate *priv = toolbar->priv;
 	const char *text;
 	char *lowercase;
-#ifdef HAVE_TYPEAHEADFIND
 	EphyEmbedFindResult result;
-#endif
-	gboolean found = TRUE, case_sensitive;
+	gboolean case_sensitive;
 
 	text = gtk_entry_get_text (GTK_ENTRY (priv->entry));
 
@@ -231,13 +206,9 @@ entry_changed_cb (GtkEntry *entry,
 	g_free (lowercase);
 
 	ephy_embed_find_set_properties (get_find (toolbar), text, case_sensitive);
-#ifdef HAVE_TYPEAHEADFIND
 	result = ephy_embed_find_find (get_find (toolbar), text, priv->links_only);
 
-	found = result != EPHY_EMBED_FIND_NOTFOUND;
 	set_status (toolbar, result);
-#endif
-	set_controls (toolbar, found, found);
 }
 
 static gboolean
@@ -546,7 +517,7 @@ ephy_find_toolbar_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphyFindToolbarClass),
 			NULL, /* base_init */
@@ -600,17 +571,11 @@ ephy_find_toolbar_set_embed (EphyFindToolbar *toolbar,
 	priv->embed = embed;
 	if (embed != NULL)
 	{
-		set_controls (toolbar, TRUE, TRUE);
 		clear_status (toolbar);
 
-		g_signal_connect_object (embed, "ge-content-change",
-					 G_CALLBACK (tab_content_changed_cb),
-					 toolbar, G_CONNECT_AFTER);
-#ifdef HAVE_TYPEAHEADFIND
 		g_signal_connect_object (embed, "ge-search-key-press",
 					 G_CALLBACK (tab_search_key_press_cb),
 					 toolbar, 0);
-#endif /* HAVE_TYPEAHEADFIND */
 
 		if (priv->find != NULL)
 		{
@@ -625,25 +590,28 @@ void
 ephy_find_toolbar_find_next (EphyFindToolbar *toolbar)
 {
 	EphyEmbedFindResult result;
-	gboolean found;
 
 	result = ephy_embed_find_find_again (get_find (toolbar), TRUE);
-
-	found = result != EPHY_EMBED_FIND_NOTFOUND;
-	set_controls (toolbar, found, found);
 	set_status (toolbar, result);
+
+	if (!GTK_WIDGET_VISIBLE(toolbar)) {
+		gtk_widget_show (GTK_WIDGET (toolbar));
+		gtk_widget_grab_focus (GTK_WIDGET (toolbar));
+	}
 }
 
 void
 ephy_find_toolbar_find_previous (EphyFindToolbar *toolbar)
 {
 	EphyEmbedFindResult result;
-	gboolean found;
 
 	result = ephy_embed_find_find_again (get_find (toolbar), FALSE);
-	found = result != EPHY_EMBED_FIND_NOTFOUND;
-	set_controls (toolbar, found, found);
 	set_status (toolbar, result);
+
+	if (!GTK_WIDGET_VISIBLE(toolbar)) {
+		gtk_widget_show (GTK_WIDGET (toolbar));
+		gtk_widget_grab_focus (GTK_WIDGET (toolbar));
+	}
 }
 
 void
@@ -671,7 +639,6 @@ ephy_find_toolbar_open (EphyFindToolbar *toolbar,
 	}
 
 	gtk_widget_show (GTK_WIDGET (toolbar));
-
 	gtk_widget_grab_focus (GTK_WIDGET (toolbar));
 }
 
