@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2003, 2004 Marco Pesenti Gritti <mpeseng@tin.it>
- *  Copyright (C) 2003, 2004 Christian Persch
+ *  Copyright © 2003, 2004 Marco Pesenti Gritti <mpeseng@tin.it>
+ *  Copyright © 2003, 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-history-window.c,v 1.105 2006/03/02 22:04:09 jframeau Exp $
+ *  $Id: ephy-history-window.c 6625 2006-10-02 20:29:35Z chpe $
  */
 
 #include "config.h"
@@ -67,6 +67,7 @@
 #include "ephy-node-common.h"
 #include "ephy-node-view.h"
 #include "ephy-bookmarks-ui.h"
+#include "ephy-gui.h"
 
 static const GtkTargetEntry page_drag_types [] =
 {
@@ -223,7 +224,7 @@ static const GtkRadioActionEntry ephy_history_radio_entries [] =
 	  N_("Show only the title column"), VIEW_TITLE },
 	{ "ViewAddress", NULL, N_("_Address"), NULL,
 	  N_("Show only the address column"), VIEW_ADDRESS },
-	{ "ViewTitleAddress", NULL, N_("T_itle and Address"), NULL,
+	{ "ViewTitleAddress", NULL, N_("Title a_nd Address"), NULL,
 	  N_("Show both the title and address columns"),
 	  VIEW_TITLE_AND_ADDRESS } 
 };
@@ -257,6 +258,9 @@ confirmation_dialog_construct (EphyHistoryWindow *editor)
 		(GTK_MESSAGE_DIALOG (dialog),
 		 _("Clearing the browsing history will cause all"
 		   " history links to be permanently deleted."));
+
+	gtk_window_group_add_window (ephy_gui_ensure_window_group (GTK_WINDOW (editor)),
+				     GTK_WINDOW (dialog));
 	
 	button = gtk_button_new_with_label (_("Cl_ear"));
 	image = gtk_image_new_from_stock (GTK_STOCK_CLEAR, GTK_ICON_SIZE_BUTTON);
@@ -560,7 +564,7 @@ ephy_history_window_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphyHistoryWindowClass),
 			NULL,
@@ -1180,6 +1184,8 @@ ephy_history_window_construct (EphyHistoryWindow *editor)
 	GtkActionGroup *action_group;
 	int url_col_id, title_col_id, details_value;
 
+	ephy_gui_ensure_window_group (GTK_WINDOW (editor));
+
 	gtk_window_set_title (GTK_WINDOW (editor), _("History"));
 	gtk_window_set_icon_name (GTK_WINDOW (editor), EPHY_STOCK_HISTORY);
 
