@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2000-2004 Marco Pesenti Gritti
- *  Copyright (C) 2003, 2004, 2006 Christian Persch
+ *  Copyright © 2000-2004 Marco Pesenti Gritti
+ *  Copyright © 2003, 2004, 2006 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-shell.h,v 1.38 2006/06/18 18:30:24 chpe Exp $
+ *  $Id: ephy-shell.h 6664 2006-11-05 20:15:25Z jframeau $
  */
 
 #ifndef EPHY_SHELL_H
@@ -62,6 +62,10 @@ typedef enum
 	EPHY_NEW_TAB_JUMP		= 1 << 9,
 	EPHY_NEW_TAB_IN_NEW_WINDOW	= 1 << 10,
 	EPHY_NEW_TAB_IN_EXISTING_WINDOW	= 1 << 11,
+
+	/* The way to load */
+	EPHY_NEW_TAB_ALLOW_FIXUP	= 1 << 12,
+	
 } EphyNewTabFlags;
 
 struct _EphyShell
