@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2003  David Bordoley
- *  Copyright (C) 2003-2004 Christian Persch
+ *  Copyright © 2003  David Bordoley
+ *  Copyright © 2003-2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-tabs-menu.c,v 1.42 2006/04/25 11:40:41 chpe Exp $
+ *  $Id: ephy-tabs-menu.c 6867 2007-01-28 20:34:16Z chpe $
  */
 
 #include "config.h"
@@ -72,7 +72,7 @@ ephy_tabs_menu_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphyTabsMenuClass),
 			NULL, /* base_init */
@@ -240,11 +240,9 @@ sync_active_tab (EphyWindow *window,
 	GtkAction *action;
 
 	tab = ephy_window_get_active_tab (window);
+	if (tab == NULL) return;
 
 	LOG ("active tab is tab %p", tab);
- 
-	g_return_if_fail (tab != NULL);
-	if (tab == NULL) return;
 
 	action = g_object_get_data (G_OBJECT (tab), DATA_KEY);
 	/* happens initially, since the ::active-tab comes before
