@@ -1,7 +1,7 @@
 /*
- *  Copyright (C) 2002 Jorn Baayen
- *  Copyright (C) 2003 Marco Pesenti Gritti
- *  Copyright (C) 2003, 2004 Christian Persch
+ *  Copyright © 2002 Jorn Baayen
+ *  Copyright © 2003 Marco Pesenti Gritti
+ *  Copyright © 2003, 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: pdm-dialog.c,v 1.63 2006/05/30 21:12:11 fpeters Exp $
+ *  $Id: pdm-dialog.c 6589 2006-09-13 11:49:01Z chpe $
  */
 
 #include "config.h"
@@ -147,7 +147,7 @@ pdm_dialog_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (PdmDialogClass),
 			NULL, /* base_init */
