@@ -1,5 +1,6 @@
 /*
- *  Copyright (C) 2002 Jorn Baayen
+ *  Copyright © 2002 Jorn Baayen
+ *  Copyright © 2003 Marco Pesenti Gritti
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,6 +15,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: pdm-dialog.h 6589 2006-09-13 11:49:01Z chpe $
  */
 
 #ifndef PDM_DIALOG_H
@@ -31,13 +34,15 @@ G_BEGIN_DECLS
 #define EPHY_IS_PDM_DIALOG_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), EPHY_TYPE_PDM_DIALOG))
 #define EPHY_PDM_DIALOG_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), EPHY_TYPE_PDM_DIALOG, PdmDialogClass))
 
-typedef struct PdmDialog PdmDialog;
-typedef struct PdmDialogClass PdmDialogClass;
-typedef struct PdmDialogPrivate PdmDialogPrivate;
+typedef struct PdmDialog	PdmDialog;
+typedef struct PdmDialogClass	PdmDialogClass;
+typedef struct PdmDialogPrivate	PdmDialogPrivate;
 
 struct PdmDialog
 {
         EphyDialog parent;
+
+	/*< private >*/
         PdmDialogPrivate *priv;
 };
 
@@ -46,9 +51,10 @@ struct PdmDialogClass
         EphyDialogClass parent_class;
 };
 
-GType         pdm_dialog_get_type         (void);
+GType	pdm_dialog_get_type	(void);
 
-EphyDialog   *pdm_dialog_new              (GtkWidget *window);
+void	pdm_dialog_open		(PdmDialog *dialog,
+				 const char *host);
 
 G_END_DECLS
 
