@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: popup-commands.c,v 1.61.2.1 2006/09/13 11:48:54 chpe Exp $
+ *  $Id: popup-commands.c 6799 2007-01-08 23:01:43Z diegoe $
  */
 
 #include "config.h"
@@ -254,7 +254,6 @@ static void
 background_download_completed (EphyEmbedPersist *persist)
 {
 	const char *bg;
-	char *type;
 	guint32 user_time;
 
 	user_time = ephy_embed_persist_get_user_time (persist);
@@ -264,7 +263,13 @@ background_download_completed (EphyEmbedPersist *persist)
 	g_object_unref (persist);
 
 	/* open the "Background Properties" capplet */
-	ephy_file_launch_desktop_file ("background.desktop", bg, user_time);
+	if (!ephy_file_launch_desktop_file ("background.desktop", bg, user_time))
+	{
+		/* If the above try didn't work, then we try the Fedora name.
+		 * This is a fix for #387206, but is actually a workaround for
+		 * bugzilla.redhat.com #201867 */
+		ephy_file_launch_desktop_file ("gnome-background.desktop", bg, user_time);
+	}
 }
 
 void
